require_relative 'test_helper'

class ChecksFollowHistoryTest < Minitest::Test
  def test_raises_for_a_handle
    client = GrowViral::Warehouse::Client.new(:development)
    assert_raises(GrowViral::HandleNotUidError) { client.has_existing_relationship?("string", 2312422) }
  end

  def test_raises_for_a_following_handle
    client = GrowViral::Warehouse::Client.new(:development)
    assert_raises(GrowViral::HandleNotUidError) { client.has_existing_relationship?(837373, "string") }
  end

  def test_true_for_200
    uid = 328383
    following_uid = 4843432

    uri = URI.parse("http://localhost:3001/follows?uid=#{uid}&following_uid=#{following_uid}")

    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '200'))

    client = GrowViral::Warehouse::Client.new(:development)
    assert client.has_existing_relationship?(uid, following_uid)
  end

  def test_false_for_404
    uid = 3478823
    following_uid = 4939383

    uri = URI.parse("http://localhost:3001/follows?uid=#{uid}&following_uid=#{following_uid}")

    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '404'))

    client = GrowViral::Warehouse::Client.new(:development)
    refute client.has_existing_relationship?(uid, following_uid)
  end
end
