require_relative 'test_helper'

module GrowViral::Warehouse
  class FetchesUsersTest < Minitest::Test
    def test_users_is_enumerable
      data = mock
      data.expects(:each)
      data.expects(:size)
      users = FetchesUsers::Users.new(data)
      users.each {}
      users.size
    end

    def test_users_returns_missing_ids
      missing_ids = mock
      users = FetchesUsers::Users.new(nil, missing_ids: missing_ids)
      assert_equal missing_ids, users.missing_ids
    end

    def test_users_returns_invalid_ids
      invalid_ids = mock
      users = FetchesUsers::Users.new(nil, invalid_ids: invalid_ids)
      assert_equal invalid_ids, users.invalid_ids
    end

    def test_users_returns_protected_ids
      protected_ids = mock
      users = FetchesUsers::Users.new(nil, protected_ids: protected_ids)
      assert_equal protected_ids, users.protected_ids
    end

    def test_users_returns_arrays_as_defaults
      users = FetchesUsers::Users.new(nil)
      assert_equal [], users.missing_ids
      assert_equal [], users.invalid_ids
      assert_equal [], users.protected_ids
    end

    def test_raises_for_a_handle
      client = GrowViral::Warehouse::Client.new(:development)
      assert_raises(GrowViral::HandleNotUidError) { client.users(["string"]) }
    end

    def test_returns_output_correctly
      uid1 = 328383
      uid2 = 39994
      uid3 = 4757392
      uid4 = 99122

      output = { 'twitter_users' => [{'id' => uid1}], 'missing_ids' => [uid2], 'invalid_ids' => [uid3], 'protected_ids' => [uid4] }
      uri = URI.parse("http://localhost:3001/tweeps/#{uid1},#{uid2}")
      Net::HTTP.expects(:get_response).with(uri).returns(mock(body: output.to_json))

      client = GrowViral::Warehouse::Client.new(:development)
      users = client.users([uid1, uid2])
      assert_equal [{'id' => uid1}], users.each {|u|u}
      assert_equal [uid2], users.missing_ids
      assert_equal [uid3], users.invalid_ids
      assert_equal [uid4], users.protected_ids
    end

    def test_posts_account_id_if_given
      uid = 328383
      account_uid = 848493

      output = { }
      uri = URI.parse("http://localhost:3001/tweeps/#{uid}?for_account=#{account_uid}")
      Net::HTTP.expects(:get_response).with(uri).returns(mock(body: output.to_json))

      client = GrowViral::Warehouse::Client.new(:development)
      users = client.users([uid], for_account: account_uid)
    end
  end
end
