require_relative 'test_helper'

class RecordsUnFollowWTest < Minitest::Test
  def test_raises_for_a_handle
    client = GrowViral::Warehouse::Client.new(:development)
    assert_raises(GrowViral::HandleNotUidError) { client.register_unfollow!("string", 2312422) }
  end

  def test_raises_for_a_following_handle
    client = GrowViral::Warehouse::Client.new(:development)
    assert_raises(GrowViral::HandleNotUidError) { client.register_unfollow!(972822, "string") }
  end

  def test_response_is_correct
    uid = 23432423
    following_uid = 342423
    now = 42

    input = {
      "uid" => uid,
      "follow_uid" => following_uid,
      "timestamp" => now
    }

    output = { "status" => "accepted" }

    uri = URI.parse("http://localhost:3001/interactions/mark_unfollowed")
    Time.expects(:now).returns(mock(to_i: 42))
    Net::HTTP.expects(:post_form).with(uri, input).returns(mock(body: output.to_json))

    client = GrowViral::Warehouse::Client.new(:development)
    actual = client.register_unfollow!(uid, following_uid)

    assert_equal output, actual
  end
end
